/**
 * The source code present in this module was extracted from typescript-rest-swagger,
 * available at https://github.com/thiagobustamante/typescript-rest-swagger.git
 * under MIT licence, and modified to work as a stand alone typescript to swagger
 * type transformer. See the original licence below for more information.
 *
 * MIT License
 *
 * Copyright (c) Thiago da Rosa de Bustamante
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
import ts from 'typescript';
export declare const keywords: ts.SyntaxKind[];
export declare function resolveType(typeNode?: ts.TypeNode): Type;
export declare function getCommonPrimitiveAndArrayUnionType(typeNode?: ts.TypeNode): Type | null;
export declare function getLiteralValue(expression: ts.Expression): any;
export declare function getFirstMatchingJSDocTagName(node: ts.Node, isMatching: (t: ts.JSDocTag) => boolean): string | undefined;
export declare function getDecoratorName(node: ts.Node, isMatching: (identifier: DecoratorData) => boolean): string | undefined;
export interface DecoratorData {
    text: string;
    arguments: Array<any>;
    typeArguments: Array<any>;
}
export declare function getDecorators(node: ts.Node, isMatching: (identifier: DecoratorData) => boolean): Array<DecoratorData>;
export interface ArrayType extends Type {
    elementType: Type;
}
export interface EnumerateType extends Type {
    enumMembers: Array<string>;
}
export interface ObjectType extends Type {
    properties: Array<Property>;
}
export interface ReferenceType extends Type {
    description: string;
    properties: Array<Property>;
    additionalProperties?: Array<Property>;
}
export interface Property {
    description: string;
    name: string;
    type: Type;
    required: boolean;
}
export interface Type {
    typeName: string;
    typeArgument?: Type;
}
export declare function getProperties(properties: Array<Property>): {
    [propertyName: string]: Schema;
};
interface Schema extends BaseSchema {
    $ref?: string;
    allOf?: [Schema];
    additionalProperties?: boolean | {
        [ref: string]: string;
    };
    properties?: {
        [propertyName: string]: Schema;
    };
    discriminator?: string;
    readOnly?: boolean;
    example?: {
        [exampleName: string]: Example;
    };
    required?: Array<string>;
}
interface BaseSchema {
    format?: string;
    title?: string;
    description?: string;
    default?: string | boolean | number | Object;
    multipleOf?: number;
    maximum?: number;
    exclusiveMaximum?: number;
    minimum?: number;
    exclusiveMinimum?: number;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
    maxItems?: number;
    minItems?: number;
    uniqueItems?: boolean;
    maxProperties?: number;
    minProperties?: number;
    enum?: [string];
    type?: string;
    items?: Schema | [Schema];
}
interface Example {
}
export {};
